#
# spec file for package xfs_undelete
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xfs_undelete
Version:        15.0
Release:        2.1
Summary:        An undelete tool for the XFS filesystem
License:        GPL-3.0-only
Group:          System/Filesystems
URL:            https://github.com/ianka/xfs_undelete
Source:         https://github.com/ianka/xfs_undelete/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  tcl >= 8.5
BuildRequires:  tcllib
Requires:       coreutils
Requires:       file
Requires:       file-magic
Requires:       tcl >= 8.5
Requires:       tcllib
BuildArch:      noarch

%description
xfs_undelete tries to recover all files on an XFS filesystem marked as
deleted. You may also specify a date or age since deletion, and file types
to ignore or to recover exclusively.

%prep
%autosetup

%build

%install
#---env-shebangs generate warnings / error messages in OBS:
sed -i -e '1 s|/usr/bin/env tclsh|/usr/bin/tclsh|' xfs_undelete

mkdir -p %{buildroot}%{_sbindir}
cp -a xfs_undelete %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_mandir}/man8
gzip -9 -c xfs_undelete.man >%{buildroot}%{_mandir}/man8/xfs_undelete.8.gz

%check
./xfs_undelete -l >/dev/null

%files
%license LICENSE
%doc README.md
%{_sbindir}/xfs_undelete
%{_mandir}/man8/xfs_undelete.8.gz

%changelog
* Mon Oct 14 2024 Manfred Schwarb <manfred99@gmx.ch>
- test execution with a simple listing call to ensure we have a
    working tcl and tcllib installation with correct search paths
* Mon Jul 29 2024 Manfred Schwarb <manfred99@gmx.ch>
- update to version 15.0:
  * added support for the XFSv5 bigtime feature
* Fri Apr  5 2024 Manfred Schwarb <manfred99@gmx.ch>
- update to version 14.0:
  * added support for version 2 inodes. This makes xfs_undelete find deleted
    files on older XFS filesystems. Kudos to Vladimir Serbinenko
  * small fixes
- update to version 13.2:
  * bugfix: listing the supported filetypes did not work with Tcl-8.5
  * manpage fixes
- update to version 13.1:
  * bugfix: fix newly introduced private lmap function for Tcl-8.5 compatibility
  * manpage and README fixes
- update to version 13.0:
  * added the -S option to ignore files larger than the specified size
  * added the -x option to ignore the specified inode numbers
  * define our own version of lmap if Tcl does not supply it.
    This adds compatibility with Tcl-8.5, it seems.
- update to version 12.1:
  * bugfix: set UTC timezone when no timezone is set
* Tue Nov  8 2022 Manfred Schwarb <manfred99@gmx.ch>
- build separate xfs_undelete.changes file
- spec file cleanup
- convert env shebang in spec file
* Sun Oct  2 2022 Jan Kandziora <jjj@gmx.de>
- v12.0 release:
  * added time range function to the -t and -T options
  * bugfix: be less picky about the magic string of deleted inodes
* Wed Nov 11 2020 Jan Kandziora <jjj@gmx.de>
- v11.0 release:
  * added the -T option to limit the files recovered to those
    modified since a given date.
  * bugfix: script failed if LANG was unset
  * added openSUSE and Arch Linux packages link to README
  * markdown and manpage fixes in README
  * manpage fixes
* Tue Jul 14 2020 Jan Kandziora <jjj@gmx.de>
- v10.0 release:
  * added --no-remount-readonly option
* Tue Jul 14 2020 Jan Kandziora <jjj@gmx.de>
- v9.1 release:
  * bugfix: be less picky about mount error messages
* Wed Jun 10 2020 Jan Kandziora <jjj@gmx.de>
- v9.0 release:
  * added -s option for specifying a start inode
* Wed Apr 15 2020 Jan Kandziora <jjj@gmx.de>
- v8.1 release:
  * manpage fixes
* Wed Apr 15 2020 Jan Kandziora <jjj@gmx.de>
- v8.0 release:
  * added automatic trimming of trailing zeroes for certain
    filetypes
  * added support for wildcard file extension and mimetype
    matching
* Fri Apr 10 2020 Jan Kandziora <jjj@gmx.de>
- v7.2 release:
  * allow working as an ordinary user on a previously
    umounted/read-only-mounted filesystem
* Wed Apr  8 2020 Jan Kandziora <jjj@gmx.de>
- v7.1 release:
  * bugfix: added a workaround against a problem with Arch
    Linux' dd
* Sun Mar 22 2020 Jan Kandziora <jjj@gmx.de>
- v7.0 release:
  * added a manpage
  * added more sanity checks on command line parameters
  * added -m option for alternative magic files passed to the
    file utility
  * added -l option for listing understood file extensions
  * changed the -r and -i options to accept comma instead of
    space-separated lists
* Thu Mar 12 2020 Jan Kandziora <jjj@gmx.de>
- v6.2 release:
  * bugfix: agcount wasn't updated from filesystem data
* Sun Feb 16 2020 Jan Kandziora <jjj@gmx.de>
- v6.1 release:
  * fixed progress message
* Sat Feb 15 2020 Jan Kandziora <jjj@gmx.de>
- v6.0 release:
  * added -i and -r options to recover only selected file types;
    skip "bin" files by default
  * agnore all files without any extent starting at loffset
    zero. These are most likely bogus.
* Sun Feb  9 2020 Jan Kandziora <jjj@gmx.de>
- v5.0 release:
  * added guessing the correct file extension; added file deletion
    time to filename
* Sun Feb  9 2020 Jan Kandziora <jjj@gmx.de>
- v4.2 release:
  * bugfix: progress status showed wrong inode number.
* Sun Feb  9 2020 Jan Kandziora <jjj@gmx.de>
- v4.1 release:
  * bugfix: remounting a busy filesystem ro may have failed
    silently and left it rw.
* Sun Feb  9 2020 Jan Kandziora <jjj@gmx.de>
- v4.0 release:
  * achieved a factor 400 speed up by traversing the inode
    B+trees instead of mindlessly checking all filesystem blocks.
  * dropped the -s start block option because of this.
* Sat Feb  8 2020 Jan Kandziora <jjj@gmx.de>
- v3.1 release:
  * bugfix: results of binary scan have to be unsigned values
* Sat Feb  8 2020 Jan Kandziora <jjj@gmx.de>
- v3.0 release:
  * removed dependency on xfs_progs in favour of parsing the
    superblock ourselves.
* Tue Feb  4 2020 Jan Kandziora <jjj@gmx.de>
- v2.1 release:
  * Silently ignore extents even a 64-bit dd cannot handle. These
    are most likely bogus.
* Mon Jan 20 2020 Jan Kandziora <jjj@gmx.de>
- v2.0 release:
  * added the -t option to limit the files recovered to those
    deleted since a given date.
* Sat Sep 21 2019 Jan Kandziora <jjj@gmx.de>
- v1.3 release:
  * bugfix: do not fail on errors within dd, ignore those
    extents instead.
  * bugfix: do not truncate recovered files if extents are
    not ordered.
* Thu Jul  4 2019 Jan Kandziora <jjj@gmx.de>
- v1.2 release:
* Thu Jul  4 2019 Jan Kandziora <jjj@gmx.de>
- v1.1 release:
* Thu Jul  4 2019 Jan Kandziora <jjj@gmx.de>
- v1.0 release:
